/**********************************************************************
* File: DefaultIsr_6.c
* Devices: TMS320F28004x
* Author: C2000 Technical Training, Texas Instruments
**********************************************************************/

#include "Lab.h"						// Main include file


//---------------------------------------------------------------------
interrupt void adcA1ISR(void)                           // PIE1.1 @ 0x000D40  ADC-A interrupt #1
{
static uint16_t *AdcBufPtr = AdcBuf;                    // Pointer to buffer
static uint16_t iQuadratureTable = 0;                   // Quadrature table index
static volatile uint16_t GPIO34_count = 0;              // Counter for pin toggle

	Interrupt_clearACKGroup(INTERRUPT_ACK_GROUP1);      // Must acknowledge the PIE group

//--- Manage the ADC interrupt flag
	ADC_clearInterruptStatus(ADCA_BASE, ADC_INT_NUMBER1);	// Clear ADCINT1 flag

//--- Read the ADC result
	*AdcBufPtr++ = ADC_readResult(ADCARESULT_BASE, ADC_SOC_NUMBER0);    // Read the result

//--- Brute-force the circular buffer
	if( AdcBufPtr == (AdcBuf + ADC_BUF_LEN) )
	{	
		AdcBufPtr = AdcBuf;						    // Rewind the pointer to beginning
	}

//--- Example: Toggle GPIO25 so we can read it with the ADC ***/
	if(DEBUG_TOGGLE == 1)
	{
        GPIO_togglePin(25);                         // Toggle the pin
	}

//--- Example: Toggle GPIO34 at a 0.5 sec rate (connected to the LED).
//             (1/50000 sec/sample)*(1 samples/int)*(x interrupts/toggle) = (0.5 sec/toggle)
//             ==> x = 25000
	if(GPIO34_count++ > 25000)					    // Toggle slowly to see the LED blink
	{
	    GPIO_togglePin(34);	                        // Toggle the pin
		GPIO34_count = 0;						    // Reset the counter
	}

//--- Write to DAC-B to create input to ADC-A0
	if(SINE_ENABLE == 1)
	{
		DacOutput = DacOffset + ((QuadratureTable[iQuadratureTable++] ^ 0x8000) >> 5);
	}
	else
	{
		DacOutput = DacOffset;
	}
    if(iQuadratureTable > (SINE_PTS - 1))            // Wrap the index
    {
        iQuadratureTable = 0;
    }
    DAC_setShadowValue(DACB_BASE, DacOutput);

}

//---------------------------------------------------------------------
interrupt void wakeISR(void)                            // PIE1.8 @ 0x000D4E  WAKE interrupt (LPM/WD)
{
	Interrupt_clearACKGroup(INTERRUPT_ACK_GROUP1);      // Must acknowledge the PIE group
  
// Next two lines for debug only - remove after inserting your ISR
	asm (" ESTOP0");                                    // Emulator Halt instruction
	while(1);
}


//--- end of file -----------------------------------------------------
