/**********************************************************************
* File: EPwm_6.c
* Devices: TMS320F28004x
* Author: C2000 Technical Training, Texas Instruments
**********************************************************************/

#include "Lab.h"				// Main include file


/**********************************************************************
* Function: InitEPwm()
*
* Description: Initializes the Enhanced PWM modules on the F28004x
**********************************************************************/
void InitEPwm(void)
{
// Must disable the clock to the ePWM modules to have all ePWM modules synchronized
	SysCtl_disablePeripheral(SYSCTL_PERIPH_CLK_TBCLKSYNC);


//---------------------------------------------------------------------
//--- Configure ePWM2 to trigger ADC SOCA at a 50 kHz rate
//---------------------------------------------------------------------
	SysCtl_resetPeripheral(SYSCTL_PERIPH_RES_EPWM2);    // Reset ePWM2

    EPWM_setTimeBaseCounterMode(EPWM2_BASE, EPWM_COUNTER_MODE_STOP_FREEZE);             // Disable the timer
    EPWM_setClockPrescaler(EPWM2_BASE, EPWM_CLOCK_DIVIDER_1, EPWM_HSCLOCK_DIVIDER_1);   // TBCLK = EPWMCLK
    EPWM_setSyncOutPulseMode(EPWM2_BASE, EPWM_SYNC_OUT_PULSE_DISABLED);                 // Disable sync-out
    EPWM_setEmulationMode(EPWM2_BASE, EPWM_EMULATION_FREE_RUN);                         // Ignore emulation suspend

	EPWM_setTimeBaseCounter(EPWM2_BASE, 0U);				        // Clear timer counter
	EPWM_setTimeBasePeriod(EPWM2_BASE, ADC_SAMPLE_PERIOD);          // Set timer period
	EPWM_setPhaseShift(EPWM2_BASE, 0U);                             // Set timer phase
	EPWM_disablePhaseShiftLoad(EPWM2_BASE);                         // Disable phase load

	EPWM_enableADCTrigger(EPWM2_BASE, EPWM_SOC_A);                               // Enable ADC SOCA event
	EPWM_setADCTriggerSource(EPWM2_BASE, EPWM_SOC_A, EPWM_SOC_TBCTR_PERIOD);     // Set SOCA on PRD event
	EPWM_setADCTriggerEventPrescale(EPWM2_BASE, EPWM_SOC_A, 1);                  // Generate SOCA on first event

	EPWM_setTimeBaseCounterMode(EPWM2_BASE, EPWM_COUNTER_MODE_UP);  // Enable the timer in count up mode


//---------------------------------------------------------------------
//--- Enable the clocks to the ePWM module.                   
//--- Note: this should be done after all ePWM modules are configured
//--- to ensure synchronization between the ePWM modules.
//---------------------------------------------------------------------
	SysCtl_enablePeripheral(SYSCTL_PERIPH_CLK_TBCLKSYNC);	// TBCLK to ePWM modules enabled

} // end InitEPwm()


//--- end of file -----------------------------------------------------
