/**********************************************************************************
* File: Lab_5_6_7.cmd -- File for Lab 5, 6, and 7 (Boot to SARAM boot mode)
* Devices: TMS320F280049
* Author: C2000 Technical Training, Texas Instruments
**********************************************************************************/

MEMORY
{
PAGE 0:    /* Program Memory */
   BEGIN_M0            : origin = 0x000000, length = 0x000002     /* Part of M0 RAM - used for "Boot to M0" bootloader mode */
   RAMLS4              : origin = 0x00A000, length = 0x000800     /* LS4 RAM, DCSM secure, CLA Program RAM */
   RAMLS5              : origin = 0x00A800, length = 0x000800     /* LS5 RAM, DCSM secure, CLA Program RAM */
   RAMGS01             : origin = 0x00C000, length = 0x004000     /* GS0-1 RAM, Parity, DMA */
   BEGIN_FLASH         : origin = 0x080000, length = 0x000002     /* Part of FLASH_BANK0_SEC0 - used for "Jump to flash" bootloader mode */
   FLASH_BANK0_SEC0    : origin = 0x080002, length = 0x000FFE     /* Part of FLASH_BANK0_SEC0 - DCSM secure */
   FLASH_BANK0_SEC1_15 : origin = 0x081000, length = 0x00F000     /* FLASH_BANK0_SEC1_15 combined - DCSM secure */
   FLASH_BANK1_SEC0_15 : origin = 0x090000, length = 0x010000     /* FLASH_BANK1_SEC0_15 combined - DCSM secure */
   RESET           (R) : origin = 0x3FFFC0, length = 0x000002     /* Part of Boot ROM */

PAGE 1:    /* Data Memory */
   BOOT_RSVD           : origin = 0x000002, length = 0x0000F3     /* Part of M0 RAM, BOOT rom will use this for stack */
   RAMM0               : origin = 0x0000F5, length = 0x00030B     /* M0 RAM */
   RAMM1               : origin = 0x000400, length = 0x000400     /* M1 RAM */
   CLA1_MSGRAMLOW      : origin = 0x001480, length = 0x000080     /* CLA to CPU Message RAM, DCSM secure */
   CLA1_MSGRAMHIGH     : origin = 0x001500, length = 0x000080     /* CPU to CLA Message RAM, DCSM secure */
   RAMLS0              : origin = 0x008000, length = 0x000800     /* LS0 RAM, DCSM secure, CLA Data RAM */
   RAMLS1              : origin = 0x008800, length = 0x000800     /* LS1 RAM, DCSM secure, CLA Data RAM */
   RAMLS2              : origin = 0x009000, length = 0x000800     /* LS2 RAM, DCSM secure, CLA Data RAM */
   RAMLS3              : origin = 0x009800, length = 0x000800     /* LS3 RAM, DCSM secure, CLA Data RAM */
   RAMLS6              : origin = 0x00B000, length = 0x000800     /* LS6 RAM, DCSM secure, CLA Data RAM */
   RAMLS7              : origin = 0x00B800, length = 0x000800     /* LS7 RAM, DCSM secure, CLA Data RAM */   
   RAMGS2              : origin = 0x010000, length = 0x002000     /* GS2 RAM, Parity, DMA */
   RAMGS3              : origin = 0x012000, length = 0x002000     /* GS3 RAM, Parity, DMA */
}
 
SECTIONS
{
/*** Compiler Required Sections ***/

   /* Program memory (PAGE 0) sections */
   .text               : > RAMGS01,               PAGE = 0
   .cinit              : > RAMGS01,               PAGE = 0
   .const              : > RAMGS01,               PAGE = 0
   .econst             : > RAMGS01,               PAGE = 0      
   .pinit              : > RAMGS01,               PAGE = 0
   .reset              : > RESET,                 PAGE = 0, TYPE = DSECT  /* Not using the .reset section */
   .switch             : > RAMGS01,               PAGE = 0
   .TI.ramfunc         : > RAMGS01,               PAGE = 0

   /* Data Memory (PAGE 1) sections */
   .bss                : > RAMM0,                 PAGE = 1
   .ebss               : > RAMM0,                 PAGE = 1
   .cio                : > RAMM0,                 PAGE = 1
   .stack              : > RAMM1,                 PAGE = 1
   .sysmem             : > RAMM1,                 PAGE = 1
   .esysmem            : > RAMM1,                 PAGE = 1

/*** User Defined Sections ***/
   codestart           : > BEGIN_M0,              PAGE = 0                /* Used by file CodeStartBranch.asm */
}

/******************* end of file ************************/
