/**********************************************************************
* File: Main_7.c -- Solution File for Lab 7
* Devices: TMS320F28004x
* Author: C2000 Technical Training, Texas Instruments
**********************************************************************/

#include "Lab.h"                          // Main include file

//--- Global Variables
uint16_t DEBUG_TOGGLE = 1;                // Used for realtime mode investigation test
uint16_t SINE_ENABLE = 0;                 // Used for DAC waveform generation
uint16_t PWM_MODULATE = 0;                // Used for PWM modulation
uint16_t AdcBuf[ADC_BUF_LEN];             // ADC buffer allocation
uint16_t DacOffset;                       // DAC offset
uint16_t DacOutput;                       // DAC output
uint32_t PwmDuty;                         // measured PWM duty cycle
uint32_t PwmPeriod;                       // measured PWM period


/**********************************************************************
* Function: main()
*
* Description: Main function for C28x workshop labs
**********************************************************************/
void main(void)
{
//--- CPU Initialization
    Device_init();                      // Initialize device and peripherals clock (FILE: device.c)
	Interrupt_initModule();             // Initializes PIE, clear PIE registers, disables CPU interrupts, and clear all CPU interrupt flags (FILE: interrupt.c)
	Interrupt_initVectorTable();        // Initialize the PIE vector table with pointers to the shell interrupt Service Routines (FILE: interrupt.c)
    InitGpio();                         // Initialize the shared GPIO pins (FILE: Gpio.c)
	InitWatchdog();						// Initialize the Watchdog Timer (FILE: WatchDog.c)

//--- Peripheral Initialization
	InitAdca();							// Initialize the ADC-A (FILE: Adc.c)
	InitDacb();                         // Initialize the DAC-B (File: Dac.c)
	InitEPwm();							// Initialize the EPwm (FILE: EPwm.c)
	InitECap();							// Initialize the ECap (FILE: ECap.c)

//--- Enable global interrupts and real-time debug
	EINT;                               // Enable global interrupts - defined as: asm(" clrc INTM"); (FILE: cpu.h)
	ERTM;                               // Enable real-time debug - defined as: asm(" clrc DBGM"); (FILE: cpu.h)

//--- Main Loop
	while(1)							// endless loop - wait for an interrupt
	{
		NOP;                            // No operation - defined as: asm(" NOP"); (FILE: cpu.h)
	}

} //end of main()


/*** end of file *****************************************************/
